@@ -7,15 +7,7 @@ MIME::Parser::Filer - manage file-output of the parser
 
 =head1 SYNOPSIS
 
-Before reading further, you should see L<MIME::Parser> to make sure that 
-you understand where this module fits into the grand scheme of things.
-Go on, do it now.  I'll wait.
-
-Ready?  Ok... now read L<"DESCRIPTION"> below, and everything else
-should make sense.
-
-
-=head2 Public interface
+Public interface:
 
     ### Create a "filer" of the desired class:
     my $filer = MIME::Parser::FileInto->new($dir);
@@ -32,10 +24,13 @@ should make sense.
     $path = $filer->output_path($head);
 
 
-=head2 Semi-public interface
+Using with MIME::Parser objects:
 
-These methods might be overriden or ignored in some subclasses, 
-so they don't all make sense in all circumstances:
+    $parser->filer($filer); 
+
+
+Semi-public interface -- these methods might be overriden or ignored
+in some subclasses, so they don't all make sense in all circumstances:
 
     ### Tweak the mapping from content-type to extension:
     $emap = $filer->output_extension_map;
@@ -43,54 +38,16 @@ so they don't all make sense in all circumstances:
 
 
 
+The protected (subclass) interface is described below.
+    
 
 =head1 DESCRIPTION
 
-
-=head2 How this class is used when parsing
-
 When a MIME::Parser decides that it wants to output a file to disk,
 it uses its "Filer" object -- an instance of a MIME::Parser::Filer 
-subclass -- to determine where to put the file.  
-
-Every parser has a single Filer object, which it uses for all
-parsing.  You can get the Filer for a given $parser like this:
-
-    $filer = $parser->filer;
-
-At the beginning of each C<parse()>, the filer's internal state
-is reset by the parser: 
-
-    $parser->filer->init_parse;
-
-The parser can then get a path for each entity in the message
-by handing that entity's header (a MIME::Head) to the filer 
-and having it do the work, like this:
-
-    $new_file = $parser->filer->output_path($head);
-
-Since it's nice to be able to clean up after a parse (especially
-a failed parse), the parser tells the filer when it has actually 
-used a path:
-
-    $parser->filer->purgeable($new_file);
-
-Then, if you want to clean up the files which were created for a
-particular parse (and also any directories that the Filer created),
-you would do this:
-
-    $parser->filer->purge;
-
-
-
-=head2 Writing your own subclasses
-
-There are two standard "Filer" subclasses (see below): 
-B<MIME::Parser::FileInto>, which throws all files from all parses
-into the same directory, and B<MIME::Parser::FileUnder> (preferred), which 
-creates a subdirectory for each message.  Hopefully, these will be 
-sufficient for most uses, but just in case...
-
+subclass -- to determine where to put the file.  There are two 
+standard "Filer" subclasses (see below).  To implement your own custom
+behavior, however, you may want to author your own Filer subclass.
 The only method you have to override is L<output_path()|/output_path>:
 
     $filer->output_path($head);
@@ -102,8 +59,7 @@ exception.
 
 The path returned by C<output_path()> should be "ready for open()":
 any necessary parent directories need to exist at that point.
-These directories can be created by the Filer, if course, and they
-should be marked as B<purgeable()> if a purge should delete them.
+These directories can be created by the Filer, if course.
 
 Actually, if your issue is more I<where> the files go than
 what they're named, you can use the default L<output_path()|/output_path>
@@ -114,7 +70,6 @@ method and just override one of its components:
     ...
 
 
-
 =head1 PUBLIC INTERFACE
 
 
@@ -129,10 +84,8 @@ This is the abstract superclass of all "filer" objects.
 use strict;
 
 ### Kit modules:
-use MIME::Tools qw(:msgtypes);
+use MIME::Tools qw();
 use File::Spec;
-use File::Path qw(rmtree);
-use MIME::WordDecoder;
 
 ### Output path uniquifiers:
 my $GFileNo = 0;
@@ -234,14 +187,9 @@ override for their own use (the default init does nothing).
 sub new {
     my ($class, @initargs) = @_;
     my $self = bless {
-	MPF_Prefix    => "msg",
-	MPF_Dir       => ".",
-	MPF_Ext       => { %DefaultTypeToExt },
-	MPF_Purgeable => [],       ### files created by the last parse
-
-	MPF_MaxName   => 80,       ### max filename before treated as evil
-	MPF_TrimRoot  => 14,       ### trim root to this length
-	MPF_TrimExt   => 3,        ### trim extension to this length
+	MPF_Prefix => "msg",
+	MPF_Dir    => ".",
+	MPF_Ext    => { %DefaultTypeToExt },
     }, $class;
     $self->init(@initargs);
     $self;
@@ -279,30 +227,16 @@ parser to avoid circular reference!
 
 sub results {
     my ($self, $results) = @_;
-    $self->{MPF_Results} = $results if (@_ > 1);
-    $self->{MPF_Results};
+    $self->{MPF_Results} = $results;
 }
 
-### Log debug messages:
 sub debug {
     my $self = shift;
-    if (MIME::Tools->debugging()) {
-	if ($self->{MPF_Results}) {
-	    unshift @_, $self->{MPF_Results}->indent;
-	    $self->{MPF_Results}->msg($M_DEBUG, @_);
-	}
-	MIME::Tools::debug(@_);
-    }
+    $self->{MPF_Results}->msg('debug', @_) if $self->{MPF_Results};
 }
-
-### Log warning messages:
 sub whine {
     my $self = shift;
-    if ($self->{MPF_Results}) {
-	unshift @_, $self->{MPF_Results}->indent;
-	$self->{MPF_Results}->msg($M_WARNING, @_);
-    }
-    MIME::Tools::whine(@_);
+    $self->{MPF_Results}->msg('warning', @_) if $self->{MPF_Results};
 }
 
 #------------------------------
@@ -311,13 +245,12 @@ sub whine {
 
 I<Instance method.>
 Prepare to start parsing a new message.
-Subclasses should always be sure to invoke the inherited method.
+Default does nothing.
 
 =cut
 
 sub init_parse {
     my $self = shift;
-    $self->{MPF_Purgeable} = [];
 }
 
 #------------------------------
@@ -330,25 +263,18 @@ in generating a disk file name?  It is if any of these are true:
 
     * it is empty
     * it is a string of dots: ".", "..", etc.
-    * it contains characters not in the set: "A" - "Z", "a" - "z",
-      "0" - "9", "-", "_", "+", "=", ".", ",", "@", "#",
-      "$", and " ".
-    * it is too long
+    * it contains a known "path" character: '/' '\' ':' '[' ']'
 
 If you just want to change this behavior, you should override 
 this method in the subclass of MIME::Parser::Filer that you use.
 
-B<Warning:> at the time this method is invoked, the FILENAME has 
-already been unmime'd into the local character set.  
-If you're using any character set other than ASCII, ISO-8859-*, 
-or UTF-8, the interpretation of the "path" characters might be 
-very different, and you will probably need to override this method.
-See L<MIME::WordDecoder/unmime> for more details.
-
 B<Note:> subclasses of MIME::Parser::Filer which override 
 output_path() might not consult this method; note, however, that
 the built-in subclasses do consult it.
 
+B<Note:> This method used to be a lot stricter, but it unnecessailry
+inconvenienced users on non-ASCII systems. 
+
 I<Thanks to Andrew Pimlott for finding a real dumb bug in the original
 version.  Thanks to Nickolay Saukh for noting that evil is in the 
 eye of the beholder.>
@@ -358,125 +284,14 @@ eye of the beholder.>
 sub evil_filename {
     my ($self, $name) = @_;
 
-    $self->debug("is this evil? '$name'");
-
     return 1 if (!defined($name) or ($name eq ''));   ### empty
-    return 1 if ($name =~ m{(^\s)|(\s+\Z)});  ### leading/trailing whitespace
     return 1 if ($name =~ m{^\.+\Z});         ### dots
-    return 1 if ($name =~ /[^-A-Z0-9_+=.,@\#\$\% ]/i); # Only allow good chars
-    return 1 if ($self->{MPF_MaxName} and
-		 (length($name) > $self->{MPF_MaxName}));
-    $self->debug("it's ok");
+    return 1 if ($name =~ tr{\\/:[]}{});      ### path characters
     0;
 }
 
 #------------------------------
 
-=item exorcise_filename FILENAME
-
-I<Instance method.>
-If a given filename is evil (see L</evil_filename>) we try to
-rescue it by performing some basic operations: shortening it,
-removing bad characters, etc., and checking each against
-evil_filename().
-
-Returns the exorcised filename (which is guaranteed to not
-be evil), or undef if it could not be salvaged.
-
-B<Warning:> at the time this method is invoked, the FILENAME has 
-already been unmime'd into the local character set.  
-If you're using anything character set other than ASCII, ISO-8859-*, 
-or UTF-8, the interpretation of the "path" characters might be very 
-very different, and you will probably need to override this method.
-See L<MIME::WordDecoder/unmime> for more details.
-
-=cut
-
-sub exorcise_filename {
-    my ($self, $fname) = @_;
-
-    ### Isolate to last path element:
-    my $last = $fname; $last =~ s{^.*[/\\\[\]:]}{};
-    if ($last and !$self->evil_filename($last)) {
-	$self->debug("looks like I can use the last path element");
-	return $last;
-    }
-
-    ### Break last element into root and extension, and truncate:
-    my ($root, $ext) = (($last =~ /^(.*)\.([^\.]+)\Z/)
-			? ($1, $2)
-			: ($last, ''));
-    ### Delete leading and trailing whitespace
-    $root =~ s/^\s+//;
-    $ext  =~ s/\s+$//;
-    $root = substr($root, 0, ($self->{MPF_TrimRoot} || 14));
-    $ext  = substr($ext,  0, ($self->{MPF_TrimExt}  ||  3));
-    $ext =~ /^\w+$/ or $ext = "dat";
-    my $trunc = $root . ($ext ? ".$ext" : '');
-    if (!$self->evil_filename($trunc)) {
-	$self->debug("looks like I can use the truncated last path element");
-	return $trunc;
-    }
-
-    ### Remove all bad characters
-    $trunc =~ s/([^-A-Z0-9_+=.,@\#\$ ])/sprintf("%%%02X", unpack("C", $1))/ige;
-    if (!$self->evil_filename($trunc)) {
-	$self->debug("looks like I can use a munged version of the truncated last path element");
-	return $trunc;
-    }
-
-    ### Hope that works:
-    undef;
-}
-
-#------------------------------
-
-=item find_unused_path DIR, FILENAME
-
-I<Instance method, subclasses only.>
-We have decided on an output directory and tentative filename,
-but there is a chance that it might already exist.  Keep
-adding a numeric suffix "-1", "-2", etc. to the filename
-until an unused path is found, and then return that path.
-
-The suffix is actually added before the first "." in the filename
-is there is one; for example:
-
-    picture.gif       archive.tar.gz      readme
-    picture-1.gif     archive-1.tar.gz    readme-1
-    picture-2.gif     archive-2.tar.gz    readme-2
-    ...               ...                 ...
-    picture-10.gif
-    ...
-
-This can be a costly operation, and risky if you don't want files
-renamed, so it is in your best interest to minimize situations
-where these kinds of collisions occur.  Unfortunately, if
-a multipart message gives all of its parts the same recommended
-filename, and you are placing them all in the same directory,
-this method might be unavoidable.
-
-=cut
-
-sub find_unused_path {
-    my ($self, $dir, $fname) = @_;
-    my $i = 0;
-    while (1) {
-
-	### Create suffixed name (from filename), and see if we can use it:
-	my $suffix = ($i ? "-$i" : "");
-	my $sname = $fname; $sname =~ s/^(.*?)(\.|\Z)/$1$suffix$2/;
-	my $path = File::Spec->catfile($dir, $sname);
-	if (! -e $path) {   ### it's good!
-	    $i and $self->whine("collision with $fname in $dir: using $path");
-	    return $path;
-	}
-	$self->debug("$path already taken");
-    } continue { ++$i; }
-}
-
-#------------------------------
-
 =item ignore_filename [YESNO]
 
 I<Instance method.>
@@ -531,13 +346,11 @@ sub output_filename {
     my ($self, $head) = @_;
 
     ### Get the recommended name:
-    my $recommended = unmime $head->recommended_filename;
+    my $recommended = $head->recommended_filename;
 
     ### Get content type:
     my ($type, $subtype) = split m{/}, $head->mime_type; $subtype ||= '';
-
-    ### Get recommended extension, being quite conservative:
-    my $recommended_ext = (($recommended and ($recommended =~ m{(\.\w+)\Z}))
+    my $recommended_ext = (($recommended and ($recommended =~ m{(.[^\.]+)\Z}))
 			   ? $1 
 			   : undef);
 
@@ -547,7 +360,7 @@ sub output_filename {
 	       $self->{MPF_Ext}{"$type/*"} ||
 	       $self->{MPF_Ext}{"*/*"} ||
 	       ".dat");
-
+    
     ### Get a prefix:
     ++$GFileNo;
     return ($self->output_prefix . "-$$-$GFileNo$ext");
@@ -655,36 +468,21 @@ sub output_path {
 
     ### Get the output directory:
     my $dir = $self->output_dir($head);
-
-    ### Get the output filename, decoding into the local character set:
-    my $fname = unmime $head->recommended_filename;
-
-    ### Can we use it:
+    
+    ### Get the output filename:
+    my $fname = $head->recommended_filename;
     if    (!defined($fname)) {
 	$self->debug("no filename recommended: synthesizing our own");
 	$fname = $self->output_filename($head);
     }
     elsif ($self->ignore_filename) {
-	$self->debug("ignoring all external filenames: synthesizing our own");
 	$fname = $self->output_filename($head);
     }
     elsif ($self->evil_filename($fname)) {
-
-	### Can we save it by just taking the last element?
-	my $ex = $self->exorcise_filename($fname);
-	if (defined($ex) and !$self->evil_filename($ex)) {
-	    $self->whine("Provided filename '$fname' is regarded as evil, ",
-			 "but I was able to exorcise it and get something ",
-			 "usable.");
-	    $fname = $ex;
-	}
-	else {
-	    $self->whine("Provided filename '$fname' is regarded as evil; ",
-			 "I'm ignoring it and supplying my own.");
-	    $fname = $self->output_filename($head);
-	}
+	$self->whine("Provided filename '$fname' is regarded as evil by\n",
+		     "this parser... I'm ignoring it and supplying my own.");
+	$fname = $self->output_filename($head);
     }
-    $self->debug("planning to use '$fname'");
 
     ### Resolve collisions and return final path:
     return $self->find_unused_path($dir, $fname);
@@ -692,55 +490,46 @@ sub output_path {
 
 #------------------------------
 
-=item purge
+=item find_unused_path DIR, FILENAME
 
-I<Instance method, final.>
-Purge all files/directories created by the last parse.
-This method simply goes through the purgeable list in reverse order 
-(see L</purgeable>) and removes all existing files/directories in it.
-You should not need to override this method.
+I<Instance method, subclasses only.>
+We have decided on an output directory and tentative filename,
+but there is a chance that it might already exist.  Keep
+adding a numeric suffix "-1", "-2", etc. to the filename
+until an unused path is found, and then return that path.
+
+The suffix is actually added before the first "." in the filename
+is there is one; for example:
+
+    picture.gif       archive.tar.gz      readme
+    picture-1.gif     archive-1.tar.gz    readme-1
+    picture-2.gif     archive-2.tar.gz    readme-2
+    ...               ...                 ...
+    picture-10.gif
+    ...
+
+This can be a costly operation, and risky if you don't want files
+renamed, so it is in your best interest to minimize situations
+where these kinds of collisions occur.  Unfortunately, if
+a multipart message gives all of its parts the same recommended
+filename, and you are placing them all in the same directory,
+this method might be unavoidable.
 
 =cut
 
-sub purge {
-    my ($self) = @_;
-    foreach my $path (reverse @{$self->{MPF_Purgeable}}) {
-	(-e $path) or next;   ### must check: might delete DIR before DIR/FILE 
-	rmtree($path, 0, 1);
-	(-e $path) and $self->whine("unable to purge: $path");
-    }
-    1;
-}
-
-#------------------------------
-
-=item purgeable [FILE]
-
-I<Instance method, final.>
-Add FILE to the list of "purgeable" files/directories (those which
-will be removed if you do a C<purge()>).
-You should not need to override this method.
-
-If FILE is not given, the "purgeable" list is returned.
-This may be used for more-sophisticated purging.
-
-As a special case, invoking this method with a FILE that is an
-arrayref will replace the purgeable list with a copy of the
-array's contents, so [] may be used to clear the list.
-
-Note that the "purgeable" list is cleared when a parser begins a 
-new parse; therefore, if you want to use purge() to do cleanup,
-you I<must> do so I<before> starting a new parse!
-
-=cut
-
-sub purgeable {
-    my ($self, $path) = @_;
-    return @{$self->{MPF_Purgeable}} if (@_ == 1);   
-
-    if (ref($path)) { $self->{MPF_Purgeable} = [ @$path ]; }
-    else            { push @{$self->{MPF_Purgeable}}, $path; }
-    1;
+sub find_unused_path {
+    my ($self, $dir, $fname) = @_;
+    my $i = 0;
+    while (1) {
+	my $suffix = ($i ? "-$i" : "");
+	my $sname = $fname; $sname =~ s/^(.*?)(\.|\Z)/$1$suffix$2/;
+	my $path = File::Spec->catfile($dir, $sname);
+	if (! -e $path) {
+	    $self->whine("collision with $sname in $dir: using $path");
+	    return $path;
+	}
+	$self->debug("$path already taken");
+    } continue { ++$i; }
 }
 
 =back
@@ -748,7 +537,6 @@ sub purgeable {
 =cut
 
 
-#------------------------------------------------------------
 #------------------------------------------------------------
 
 =head2 MIME::Parser::FileInto
@@ -797,8 +585,6 @@ sub output_dir {
 
 
 
-
-#------------------------------------------------------------
 #------------------------------------------------------------
 
 =head2 MIME::Parser::FileUnder
@@ -880,26 +666,20 @@ sub init {
 sub init_parse {
     my $self = shift;
 
-    ### Invoke inherited method first!
-    $self->SUPER::init_parse;
-
     ### Determine the subdirectory of ther base to use:
     my $subdir = (defined($self->{MPFU_DirName})
 		  ?       $self->{MPFU_DirName}
 		  :       ("msg-".scalar(time)."-$$-".$GSubdirNo++));
     $self->debug("subdir = $subdir");
     
-    ### Determine full path to the per-message output directory:
+    ### Determine full path to output directory:
     $self->{MPFU_Dir} = File::Spec->catfile($self->{MPFU_Base}, $subdir);
 
-    ### Remove and re-create the per-message output directory:
+    ### Remove and re-create it:
     rmtree $self->output_dir if $self->{MPFU_Purge};
     (-d $self->output_dir) or
 	mkdir $self->output_dir, 0700 or 
 	    die "mkdir ".$self->output_dir.": $!\n";
-
-    ### Add the per-message output directory to the puregables:
-    $self->purgeable($self->output_dir);
     1;
 }
 
@@ -932,5 +712,5 @@ it and/or modify it under the same terms as Perl itself.
 
 =head1 VERSION
 
-$Revision$
+$Revision: 5.7 $
 
